import java.io.*;
import java.net.*;

public class NetworkComm 
{
	/* We have two users. ID: 1 pw: 126809
    ID: 2 pw: 273744 */
	private String _user;
    private String _password;
    private String _opponent;
    private final String _machine  = "icarus.engr.uconn.edu";
    private int port = 3499;
    private Socket _socket = null;
    private PrintWriter _out = null;
    private BufferedReader _in = null;

    private String _gameID;
    private String _myColor;
    private MartyMcfly gameWindow;
  
    public NetworkComm(String usr, String pass, String opp, MartyMcfly mm)
    {	
    	_user = usr;
		_password = pass;
		_opponent = opp;
		gameWindow = mm;
		
		System.out.println("Creating socket...");
		_socket = openSocket();
		System.out.println("Socket created. Gathering game data...");
		
		String readMessage;
		try{
		readAndEcho(); // start message
		readAndEcho(); // ID query
		writeMessageAndEcho(_user); // user ID
		readAndEcho(); // password query 
		writeMessage(_password);  // password
		readAndEcho(); // opponent query
		writeMessageAndEcho(_opponent);  // opponent
		
		//setGameID(readAndEcho().substring(5,9)); // game 
		readMessage = readAndEcho().substring(5);
		System.out.println(readMessage);
		setGameID(readMessage);
		
		setColor(readAndEcho().substring(6,11));  // color
		} catch  (IOException e) {
    	    gameWindow.exitGame("Error while trying to connect with server!\n\tExiting");
    	}
    }
    
    public void endCommWithServer()	//this closes the socket with the server
    {
    	try{ _socket.close(); } 
    	catch  (IOException e) {
    	    System.out.println("NetworkCom.endCommWithServer: Failed in close socket.");
    	}
    }

    public Socket getSocket(){
	return _socket;
    }

    public PrintWriter getOut(){
	return _out;
    }

    public BufferedReader getIn(){
	return _in;
    }
     
    public void setGameID(String id){
	_gameID = id;
    }
    
    public String getGameID() {
	return _gameID;
    }

    public void setColor(String color){
	_myColor = color;
    }
    
    public String getColor() {
	return _myColor;
    }

    public String readAndEcho() throws IOException
    {
	String readMessage = _in.readLine();
	System.out.println("NetworkCom Reading in: "+readMessage);
	return readMessage;
    }

    public void writeMessage(String message) throws IOException
    {
	_out.print(message+"\r\n");  
	_out.flush();
    }
 
    public void writeMessageAndEcho(String message) throws IOException
    {
	_out.print(message+"\r\n");  
	_out.flush();
	System.out.println("NetworkCom Sent data: "+ message);
    }
			       
    public  Socket openSocket()
    {
    	//Create socket connection, adapted from Sun example
    	try
    	{
    		_socket = new Socket(_machine, port);
    		_out = new PrintWriter(_socket.getOutputStream(), true);
    		_in = new BufferedReader(new InputStreamReader(_socket.getInputStream()));
    	} catch (UnknownHostException e) 
    	{
    		gameWindow.exitGame("Connection with host " + _machine+" failed");
    	} catch  (IOException e) {
    		gameWindow.exitGame("IO Exception while trying to create socket");
     }
     return _socket;
  }
}
